==> devpulse_cli-0.1.3.tar.gz: devpulse_cli-0.1.3/devpulse/commands/config.py <==
import typer
import json
from pathlib import Path

app = typer.Typer(help="Configuration management")

CONFIG_DIR = Path.home() / ".devpulse"


@app.command()
def show(key: str = typer.Argument(None, help="Config key (optional)")):
    """Show configuration."""
    if key:
        typer.echo(f"⚙️  {key}: (not set)")
    else:
        typer.echo("⚙️  DevPulse Configuration:")
        typer.echo("user.name: (not set)")
        typer.echo("theme: light")
        typer.echo("notifications: enabled")


@app.command()
def set(key: str = typer.Argument(..., help="Config key"), value: str = typer.Argument(..., help="Config value")):
    """Set a configuration value."""
    typer.echo(f"✅ Set {key} = {value}")


@app.command()
def get(key: str = typer.Argument(..., help="Config key")):
    """Get a configuration value."""
    typer.echo(f"⚙️  {key}: (not set)")


@app.command()
def reset(confirm: bool = typer.Option(False, "--confirm", "-c")):
    """Reset configuration to defaults."""
    if not confirm:
        typer.confirm("Reset all configuration to defaults?", abort=True)
    typer.echo("✅ Configuration reset to defaults")


@app.command()
def list():
    """List all configuration."""
    typer.echo("⚙️  All Configuration:")
    typer.echo("No configuration set yet")


@app.command()
def import_config(file: str = typer.Argument(..., help="Config file path")):
    """Import configuration from file."""
    typer.echo(f"📥 Importing config from {file}")
    typer.echo("✅ Configuration imported!")


@app.command()
def export_config(file: str = typer.Argument("devpulse.json", help="Output file")):
    """Export configuration to file."""
    typer.echo(f"📤 Exporting config to {file}")
    typer.echo("✅ Configuration exported!")

==> devpulse_cli-0.2.0.tar.gz: devpulse_cli-0.2.0/devpulse/commands/config.py <==
import typer
import json
from pathlib import Path

app = typer.Typer(help="Configuration management")

CONFIG_DIR = Path.home() / ".devpulse"


@app.command()
def show(key: str = typer.Argument(None, help="Config key (optional)")):
    """Show configuration."""
    if key:
        typer.echo(f"[*] {key}: (not set)")
    else:
        typer.echo("[*] DevPulse Configuration:")
        typer.echo("user.name: (not set)")
        typer.echo("theme: light")
        typer.echo("notifications: enabled")


@app.command()
def set(key: str = typer.Argument(..., help="Config key"), value: str = typer.Argument(..., help="Config value")):
    """Set a configuration value."""
    typer.echo(f"[OK] Set {key} = {value}")


@app.command()
def get(key: str = typer.Argument(..., help="Config key")):
    """Get a configuration value."""
    typer.echo(f"[*] {key}: (not set)")


@app.command()
def reset(confirm: bool = typer.Option(False, "--confirm", "-c")):
    """Reset configuration to defaults."""
    if not confirm:
        typer.confirm("Reset all configuration to defaults?", abort=True)
    typer.echo("[OK] Configuration reset to defaults")


@app.command()
def list():
    """List all configuration."""
    typer.echo("[*] All Configuration:")
    typer.echo("No configuration set yet")


@app.command()
def import_config(file: str = typer.Argument(..., help="Config file path")):
    """Import configuration from file."""
    typer.echo(f"📥 Importing config from {file}")
    typer.echo("[OK] Configuration imported!")


@app.command()
def export_config(file: str = typer.Argument("devpulse.json", help="Output file")):
    """Export configuration to file."""
    typer.echo(f"📤 Exporting config to {file}")
    typer.echo("[OK] Configuration exported!")
